org.openqa.selenium.server.browserlaunchers.locators (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

## Package org.openqa.selenium.server.browserlaunchers.locators

Interface Summary
BrowserLocator | Discovers a valid browser installation on local system.

Class Summary
Firefox2Locator | Discovers a valid Firefox 2.x installation on local system.
Firefox2or3Locator | Discovers a valid Firefox installation on local system.
Firefox3Locator | Discovers a valid Firefox 2.x or 3.x installation on local system.
FirefoxLocator | Discovers a valid Firefox installation on local system.
GoogleChromeLocator | Discovers a valid Google Chrome installation on local system.
InternetExplorerLocator | Discovers a valid Internet Explorer installation on local system.
SafariLocator | Discovers a valid Internet Explorer installation on local system.
SingleBrowserLocator | Discovers a valid browser installation on local system.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.